function n2 = dist2(x, c)
%DIST2	Calculates squared distance between two sets of points.
%
%	Description
%	D = DIST2(X, C) takes two matrices of vectors and calculates the
%	squared Euclidean distance between them.  Both matrices must be of
%	the same column dimension.  If X has M rows and N columns, and C has
%	L rows and N columns, then the result has M rows and L columns.  The
%	I, Jth entry is the  squared distance from the Ith row of X to the
%	Jth row of C.
%
%	See also
%	GMMACTIV, KMEANS, RBFFWD
%

%	Copyright (c) Christopher M Bishop, Ian T Nabney (1996, 1997)
%	Modified for speedup using bsxfun() by SJ Yoon, Univ. of Michigan (2014)

[~, dimx] = size(x);
[~, dimc] = size(c);
if dimx ~= dimc
	error('dist2.m: Data dimension does not match dimension of centres')
end

n2 = bsxfun(@plus, sum((x.^2),2), sum((c.^2),2)') - 2*(x*(c'));
